# はじめに！

Rapunzel へようこそ！これはPythonとRの現代的な開発環境です。以下はいくつかの便利なキーボードショートカットです。


## プロジェクトフォルダとファイルの操作

- [`Ctrl+Shift+O`: プロジェクトフォルダを開く](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: プロジェクトフォルダからファイルを開く](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: 空のドキュメントを作成する](opensesame://event.ide_new_file)


## 素早く操作する

- [`Ctrl+Shift+P`: コマンドパレットを起動する](opensesame://event.command_palette_activate)
- `Ctrl+R`: 関数やクラスにジャンプする


## コードの実行

- `F5`: プロジェクトまたはファイルを実行する
- `F9`: 選択範囲、セル、または現在の行を実行する